;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "flymake-ansible-lint" "20250920.1926"
  "A Flymake backend for ansible-lint."
  '((emacs "26.1"))
  :url "https://github.com/jamescherti/flymake-ansible-lint.el"
  :commit "fcd15eafd96afa35f4b3d52f320d949d110bf573"
  :revdesc "fcd15eafd96a"
  :keywords '("tools"))
